# Critical Instructions for Gemini Agents

**STOP AND READ:** Before starting any work on this repository, you MUST read [`AGENTS.md`](AGENTS.md).

`AGENTS.md` is the canonical handbook for contributing to `weakincentives`. It defines the engineering standards, testing doctrine, and design-by-contract expectations that you are required to follow.
